==> duiba-biz-tool-0.0.7-rc2-sources.jar: cn/com/duiba/cloud/biz/tool/message/ErrorMeta.java <==
package cn.com.duiba.cloud.biz.tool.message;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.cloud.biz.tool.AppContext;
import lombok.Setter;

import java.util.Locale;
import java.util.Objects;

/**
 * 错误元对象
 *
 * @author zhoujunquan@duiba.com.cn
 * @version 1.0
 * @date 2021/11/20 12:36 下午
 **/
@Setter
public class ErrorMeta implements Error<String> {
    private String code;
    private String msg;
    private String isvModule;

    public ErrorMeta(String isvModule, String code, String msg) {
        super();
        Objects.requireNonNull(isvModule, "isvModule不能为null");
        Objects.requireNonNull(code, "code不能为null");
        Objects.requireNonNull(msg, "msg不能为null");
        this.isvModule = isvModule;
        this.code = code;
        this.msg = msg;
    }

    public ErrorMeta(String code, String msg) {
        super();
        this.code = code;
        this.msg = msg;
    }

    @Override
    public String getMsg() {
        return msg;
    }

    @Override
    public String getCode() {
        return code;
    }

    public String getIsvModule() {
        return isvModule;
    }

    /**
     * 获取bizException
     *
     * @param params 占位符
     * @return bizException
     */
    public BizException getException(Object... params) {
        return this.getException(AppContext.getLocal(), params);
    }

    /**
     * 获取bizException
     *
     * @param locale 请求中的local
     * @param params 占位符
     * @return bizException
     */
    public BizException getException(Locale locale, Object... params) {
        Error<String> error = ErrorFactory.getError(this, locale, params);
        return new BizException(error.getMsg()).withCode(error.getCode());
    }
}

==> duiba-biz-tool-0.0.12-20220330.024340-1-sources.jar: cn/com/duiba/cloud/biz/tool/message/ErrorMeta.java <==
package cn.com.duiba.cloud.biz.tool.message;

import cn.com.duiba.boot.exception.BizException;
import lombok.Setter;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.Locale;
import java.util.Objects;

/**
 * 错误元对象
 *
 * @author zhoujunquan@duiba.com.cn
 * @version 1.0
 * @date 2021/11/20 12:36 下午
 * @since 0.0.1
 **/
@Setter
public class ErrorMeta implements Error<String> {
    private String code;
    private String msg;
    private String isvModule;

    public ErrorMeta(String isvModule, String code, String msg) {
        super();
        Objects.requireNonNull(isvModule, "isvModule不能为null");
        Objects.requireNonNull(code, "code不能为null");
        Objects.requireNonNull(msg, "msg不能为null");
        this.isvModule = isvModule;
        this.code = code;
        this.msg = msg;
    }

    public ErrorMeta(String code, String msg) {
        super();
        this.code = code;
        this.msg = msg;
    }

    @Override
    public String getMsg() {
        return msg;
    }

    @Override
    public String getCode() {
        return code;
    }

    public String getIsvModule() {
        return isvModule;
    }

    /**
     * 获取bizException
     *
     * @param params 占位符
     * @return bizException
     */
    public BizException getException(Object... params) {
        Locale locale;
        RequestAttributes requestAttributes = RequestContextHolder.getRequestAttributes();
        if (requestAttributes != null) {
            HttpServletRequest request = ((ServletRequestAttributes) requestAttributes).getRequest();
            locale = request.getLocale();
        } else {
            locale = Locale.SIMPLIFIED_CHINESE;
        }
        return this.getException(locale, params);
    }

    /**
     * 获取bizException
     *
     * @param locale 请求中的local
     * @param params 占位符
     * @return bizException
     */
    public BizException getException(Locale locale, Object... params) {
        Error<String> error = ErrorFactory.getError(this, locale, params);
        return new BizException(error.getMsg()).withCode(error.getCode());
    }
}
